aboutsummaryrefslogtreecommitdiffstats
path: root/libbe
diff options
context:
space:
mode:
authorW. Trevor King <wking@drexel.edu>2010-01-03 11:33:56 -0500
committerW. Trevor King <wking@drexel.edu>2010-01-03 11:33:56 -0500
commit3dc696a100fa912296dc236f465f47049387d2a4 (patch)
treeb6e1fc212ee8ef768c14638b27f890b155a5cb28 /libbe
parentf08a1e8e195b37bef4bc78e5f66ae730c9ee061e (diff)
downloadbugseverywhere-3dc696a100fa912296dc236f465f47049387d2a4.tar.gz
Changed `be list --uuids` to `be list --ids`
Diffstat (limited to 'libbe')
-rw-r--r--libbe/command/list.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/libbe/command/list.py b/libbe/command/list.py
index 8b5cb4e..8baeaa2 100644
--- a/libbe/command/list.py
+++ b/libbe/command/list.py
@@ -108,14 +108,14 @@ class List (libbe.command.Command):
arg=libbe.command.Argument(
name='sort', metavar='SORT', default=None,
completion_callback=libbe.command.util.Completer(AVAILABLE_CMPS))),
- libbe.command.Option(name='uuids', short_name='u',
- help='Only print the bug UUIDS'),
+ libbe.command.Option(name='ids', short_name='i',
+ help='Only print the bug IDS'),
libbe.command.Option(name='xml', short_name='x',
help='Dump output in XML format'),
])
# parser.add_option("-S", "--sort", metavar="SORT-BY", dest="sort_by",
# help="Adjust bug-sort criteria with comma-separated list SORT-BY. e.g. \"--sort creator,time\". Available criteria: %s" % ','.join(AVAILABLE_CMPS), default=None)
# # boolean options. All but uuids and xml are special cases of long forms
# ("w", "wishlist", "List bugs with 'wishlist' severity"),
# ("i", "important", "List bugs with >= 'serious' severity"),
# ("A", "active", "List all active bugs"),
@@ -151,9 +151,9 @@ class List (libbe.command.Command):
bugs = self._sort_bugs(bugs, cmp_list)
# print list of bugs
- if params['uuids'] == True:
+ if params['ids'] == True:
for bug in bugs:
- print >> self.stdout, bug.uuid
+ print >> self.stdout, bug.id.user()
else:
self._list_bugs(bugs, xml=params['xml'])
bugdir.storage.writeable = writeable
@@ -108,14 +108,14 @@ class List (libbe.command.Command):
# parser.add_option("-S", "--sort", metavar="SORT-BY", dest="sort_by",
# help="Adjust bug-sort criteria with comma-separated list SORT-BY. e.g. \"--sort creator,time\". Available criteria: %s" % ','.join(AVAILABLE_CMPS), default=None)
-# # boolean options. All but uuids and xml are special cases of long forms
+# # boolean options. All but ids and xml are special cases of long forms
# ("w", "wishlist", "List bugs with 'wishlist' severity"),
# ("i", "important", "List bugs with >= 'serious' severity"),